==> representative_image-8.x-1.0.tar.gz: representative_image/tests/src/FunctionalJavascript/RepresentativeImageTestBase.php <==
<?php

namespace Drupal\Tests\representative_image\FunctionalJavascript;

use Drupal\FunctionalJavascriptTests\DrupalSelenium2Driver;
use Drupal\FunctionalJavascriptTests\WebDriverTestBase;
use Drupal\Tests\image\Kernel\ImageFieldCreationTrait;
use Drupal\Tests\TestFileCreationTrait;

/**
 * Contains common logic for functional tests.
 */
abstract class RepresentativeImageTestBase extends WebDriverTestBase {

  use ImageFieldCreationTrait;
  use TestFileCreationTrait;

  /**
   * The file system service.
   *
   * @var \Drupal\Core\File\FileSystem
   */
  protected $fileSystem;

  /**
   * The node storage service.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $nodeStorage;

  /**
   * The representative image picker service.
   *
   * @var \Drupal\representative_image\RepresentativeImagePicker
   */
  protected $representativeImagePicker;

  /**
   * The array of the default image file being used by representative_image.
   *
   * @var array
   */
  protected $defaultImageFile;

  /**
   * {@inheritdoc}
   */
  protected $minkDefaultDriverClass = DrupalSelenium2Driver::class;

  /**
   * {@inheritdoc}
   */
  public static $modules = [
    'block',
    'field_ui',
    'file',
    'image',
    'node',
    'representative_image',
    'system',
    'user',
    'views_ui',
  ];

  /**
   * The admin user account.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    $this->fileSystem = \Drupal::service('file_system');
    $this->nodeStorage = \Drupal::entityTypeManager()->getStorage('node');
    $this->representativeImagePicker = \Drupal::service('representative_image.picker');

    $this->adminUser = $this->drupalCreateUser([
      'access content',
      'access administration pages',
      'administer site configuration',
      'administer image styles',
      'administer nodes',
      'administer node display',
      'administer content types',
      'administer node fields',
      'bypass node access',
      'administer users',
      'administer user fields',
      'administer views',
    ]);
    $this->drupalLogin($this->adminUser);
    $this->drupalPlaceBlock('local_tasks_block');
    $this->setUpArticleContentType();
  }

  /**
   * Configures the article content type for testing representative image.
   *
   * Adds two image fields and a representative image field. Then hides
   * the image fields from the default display and shows the
   * representative image field.
   */
  protected function setUpArticleContentType() {
    // Create article content type with two image fields.
    $this->defaultImageFile = $this->randomFile('image');

    $this->drupalCreateContentType(['type' => 'article', 'name' => 'Article']);
    $this->createImageField('field_image1', 'article');
    $this->createImageField('field_image2', 'article');

    $page = $this->getSession()->getPage();
    $assert_session = $this->assertSession();

    // Add representative image field with default image. Set it to field1.
    $this->drupalGet('admin/structure/types/manage/article/fields/add-field');
    $page->fillField('new_storage_type', 'representative_image');
    $assert_session->waitForElementVisible('css', '[name="label"]');
    $page->fillField('label', 'Representative image');
    $machine_name = $assert_session->waitForElementVisible('css', '[name="label"] + * .machine-name-value');
    $this->assertNotEmpty($machine_name);
    $page->pressButton('Save and continue');

    $page->attachFileToField('files[settings_default_image_uuid]', $this->fileSystem->realpath($this->defaultImageFile->uri));
    $assert_session->assertWaitOnAjaxRequest();
    $page->pressButton('Save field settings');

    // Adjust display settings so only Representative Image is shown.
    // Toggle row weight selects as visible.
    $this->drupalGet('admin/structure/types/manage/article/display');
    $page->findButton('Show row weights')->click();
    $page->fillField('fields[field_representative_image][region]', 'content');
    $assert_session->assertWaitOnAjaxRequest();
    $page->fillField('fields[field_image1][region]', 'hidden');
    $assert_session->assertWaitOnAjaxRequest();
    $page->fillField('fields[field_image2][region]', 'hidden');
    $assert_session->assertWaitOnAjaxRequest();
    $page->pressButton('Save');
    $assert_session->assertWaitOnAjaxRequest();

    // @todo Need to do this or
    //   RepresentativeImagePicker::getRepresentativeImageField() will return
    //   ''.
    drupal_flush_all_caches();
  }

  /**
   * Correct field assertion for generated image.
   *
   * Asserts that an image generated by getTestFiles(image) was displayed
   * correctly.
   *
   * @param object $image
   *   An image object as returned by getTestFiles(image).
   * @param string $haystack
   *   (optional) A string to search for the image path. If provided pregmatch
   *   will be used otherwise assertPattern will be called.
   * @param string $message
   *   (optional) The message to display with the test results.
   */
  public function assertImage($image, $haystack = '', $message = '') {
    $message = empty($message) ? $image->name . ' was correctly displayed' : $message;
    list($filename, $extension) = explode('.', $image->filename);
    $pattern = '/' . $filename . '(_?[0-9]?\.{1})' . $extension . '/';

    if (!empty($haystack)) {
      $this->assertTrue((bool) preg_match($pattern, $haystack), $message);
    }
    else {
      $this->assertSession()->responseMatches($pattern);
    }
  }

  /**
   * Provides a random image object.
   *
   * @param string $type
   *   The type of file to be created for testing purposes.
   *
   * @return object
   *   A file object which has the following attributes:
   *   - $file->url (for example, public://image-2.jpg)
   *   - $file->filename (for example, image-2.jpg)
   *   - $file->name (for example, image-2)
   */
  public function randomFile($type = 'image') {
    // Get all test images in the form of an array.
    /** @var \stdClass[] $files */
    $files = $this->getTestFiles($type);
    // Get the next one on the list, wrapping around if necessary.
    static $i = 0;
    return $files[($i++) % count($files)];
  }

}

==> representative_image-8.x-1.1.tar.gz: representative_image/tests/src/FunctionalJavascript/RepresentativeImageTestBase.php <==
<?php

namespace Drupal\Tests\representative_image\FunctionalJavascript;

use Drupal\FunctionalJavascriptTests\DrupalSelenium2Driver;
use Drupal\FunctionalJavascriptTests\WebDriverTestBase;
use Drupal\Tests\image\Kernel\ImageFieldCreationTrait;
use Drupal\Tests\TestFileCreationTrait;

/**
 * Contains common logic for functional tests.
 */
abstract class RepresentativeImageTestBase extends WebDriverTestBase {

  use ImageFieldCreationTrait;
  use TestFileCreationTrait;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * The file system service.
   *
   * @var \Drupal\Core\File\FileSystem
   */
  protected $fileSystem;

  /**
   * The node storage service.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $nodeStorage;

  /**
   * The representative image picker service.
   *
   * @var \Drupal\representative_image\RepresentativeImagePicker
   */
  protected $representativeImagePicker;

  /**
   * The array of the default image file being used by representative_image.
   *
   * @var array
   */
  protected $defaultImageFile;

  /**
   * {@inheritdoc}
   */
  protected $minkDefaultDriverClass = DrupalSelenium2Driver::class;

  /**
   * {@inheritdoc}
   */
  public static $modules = [
    'block',
    'field_ui',
    'file',
    'image',
    'node',
    'representative_image',
    'system',
    'user',
    'views_ui',
  ];

  /**
   * The admin user account.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    $this->fileSystem = \Drupal::service('file_system');
    $this->nodeStorage = \Drupal::entityTypeManager()->getStorage('node');
    $this->representativeImagePicker = \Drupal::service('representative_image.picker');

    $this->adminUser = $this->drupalCreateUser([
      'access content',
      'access administration pages',
      'administer site configuration',
      'administer image styles',
      'administer nodes',
      'administer node display',
      'administer content types',
      'administer node fields',
      'bypass node access',
      'administer users',
      'administer user fields',
      'administer views',
    ]);
    $this->drupalLogin($this->adminUser);
    $this->drupalPlaceBlock('local_tasks_block');
    $this->setUpArticleContentType();
  }

  /**
   * Configures the article content type for testing representative image.
   *
   * Adds two image fields and a representative image field. Then hides
   * the image fields from the default display and shows the
   * representative image field.
   */
  protected function setUpArticleContentType() {
    // Create article content type with two image fields.
    $this->defaultImageFile = $this->randomFile('image');

    $this->drupalCreateContentType(['type' => 'article', 'name' => 'Article']);
    $this->createImageField('field_image1', 'article');
    $this->createImageField('field_image2', 'article');

    $page = $this->getSession()->getPage();
    $assert_session = $this->assertSession();

    // Add representative image field with default image. Set it to field1.
    $this->drupalGet('admin/structure/types/manage/article/fields/add-field');
    $page->fillField('new_storage_type', 'representative_image');
    $assert_session->waitForElementVisible('css', '[name="label"]');
    $page->fillField('label', 'Representative image');
    $machine_name = $assert_session->waitForElementVisible('css', '[name="label"] + * .machine-name-value');
    $this->assertNotEmpty($machine_name);
    $page->pressButton('Save and continue');

    $page->attachFileToField('files[settings_default_image_uuid]', $this->fileSystem->realpath($this->defaultImageFile->uri));
    $assert_session->assertWaitOnAjaxRequest();
    $page->pressButton('Save field settings');

    // Adjust display settings so only Representative Image is shown.
    // Toggle row weight selects as visible.
    $this->drupalGet('admin/structure/types/manage/article/display');
    $page->findButton('Show row weights')->click();
    $page->fillField('fields[field_representative_image][region]', 'content');
    $assert_session->assertWaitOnAjaxRequest();
    $page->fillField('fields[field_image1][region]', 'hidden');
    $assert_session->assertWaitOnAjaxRequest();
    $page->fillField('fields[field_image2][region]', 'hidden');
    $assert_session->assertWaitOnAjaxRequest();
    $page->pressButton('Save');
    $assert_session->assertWaitOnAjaxRequest();

    // @todo Need to do this or
    //   RepresentativeImagePicker::getRepresentativeImageField() will return
    //   ''.
    drupal_flush_all_caches();
  }

  /**
   * Correct field assertion for generated image.
   *
   * Asserts that an image generated by getTestFiles(image) was displayed
   * correctly.
   *
   * @param object $image
   *   An image object as returned by getTestFiles(image).
   * @param string $haystack
   *   (optional) A string to search for the image path. If provided pregmatch
   *   will be used otherwise assertPattern will be called.
   * @param string $message
   *   (optional) The message to display with the test results.
   */
  public function assertImage($image, $haystack = '', $message = '') {
    $message = empty($message) ? $image->name . ' was correctly displayed' : $message;
    [$filename, $extension] = explode('.', $image->filename);
    $pattern = '/' . $filename . '(_?[0-9]?\.{1})' . $extension . '/';

    if (!empty($haystack)) {
      $this->assertTrue((bool) preg_match($pattern, $haystack), $message);
    }
    else {
      $this->assertSession()->responseMatches($pattern);
    }
  }

  /**
   * Provides a random image object.
   *
   * @param string $type
   *   The type of file to be created for testing purposes.
   *
   * @return object
   *   A file object which has the following attributes:
   *   - $file->url (for example, public://image-2.jpg)
   *   - $file->filename (for example, image-2.jpg)
   *   - $file->name (for example, image-2)
   */
  public function randomFile($type = 'image') {
    // Get all test images in the form of an array.
    /** @var \stdClass[] $files */
    $files = $this->getTestFiles($type);
    // Get the next one on the list, wrapping around if necessary.
    static $i = 0;
    return $files[($i++) % count($files)];
  }

}
